require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe "Bipbop" do
  let(:bipbop) { Bipbop.new(ENV['BIPBOP_API_KEY']) }
  describe 'api key' do
    context 'environment variable present' do
      before { ENV.stub(:[]).with('BIPBOP_API_KEY').and_return('env api key') }
      it { Bipbop.new('api key').api_key.should == 'api key' }
      it { Bipbop.new.api_key.should == 'env api key' }
    end
    context 'no environment variable' do
      before { ENV.stub(:[]).with('BIPBOP_API_KEY').and_return(nil) }
      it { Bipbop.new('api key').api_key.should == 'api key' }
      it { Bipbop.new.api_key.should be_nil }
    end
  end
  describe 'cpfcnpj' do
    context 'invalid', vcr: { cassette_name: 'bipbop/cpfcnpj/invalid' } do
      it { bipbop.cpfcnpj(documento: '99999999999').should be_nil }
    end
    context 'valid cpf', vcr: { cassette_name: 'bipbop/cpfcnpj/valid-cpf' } do
      it { bipbop.cpfcnpj(documento: '09116059751').should == {"nome"=>'RAFAEL DE LIMA PAULA'} }
    end
    context 'valid cnpj', vcr: { cassette_name: 'bipbop/cpfcnpj/valid-cnpj' } do
      it { bipbop.cpfcnpj(documento: '05813794000126').should == {"nome"=>'BOLETO SIMPLES COBRANCAS LTDA  - ME'} }
    end
  end
  describe 'social' do
    context 'invalid', vcr: { cassette_name: 'bipbop/social/invalid' } do
      it { bipbop.social(documento: '9').should == {"influence"=>"20", "confidence"=>"42", "confidence_influence"=>"43", "confidence_criteria"=>"40"} }
    end
    context 'document', vcr: { cassette_name: 'bipbop/social/valid-document' } do
      it { bipbop.social(documento: '09116059751').should == {"name"=>"RAFAEL DE LIMA PAULA", "gender" => "male", "approximate_age"=>"30", "hash"=>"6CzXsZA09xMgXrHmJHUNY5X0cu7fv5yXwPGVX/i7nVE6awYftn5LpsVvdeoqbuMfBGdKIm0t1F+jrdifMraoyA==", "criteria"=>"A1", "buy_limit"=>"10214.87", "buy_avg"=>"268.33", "influence"=>"52", "confidence"=>"57", "confidence_influence"=>"56", "confidence_criteria"=>"59"} }
    end
    context 'document with email', vcr: { cassette_name: 'bipbop/social/valid-document-and-email' } do
      it { bipbop.social(documento: '09116059751', email: 'contato@rafael.adm.br').should == {"name"=>"RAFAEL DE LIMA PAULA", "gender" => "male", "approximate_age"=>"30", "hash"=>"D9C1OOc/DF5kubLGgKxSDlGL3owYz9+eZx/Wz423G3U5lj+ZqfZF7fv3f2m4GNEHSkwFpEFuaX90fCB4Vug8EA==", "criteria"=>"A1", "buy_limit"=>"10214.87", "buy_avg"=>"268.33", "influence"=>"52", "confidence"=>"57", "confidence_influence"=>"56", "confidence_criteria"=>"59"} }
    end
  end
  describe 'perfileconomico' do
    context 'invalid', vcr: { cassette_name: 'bipbop/perfileconomico/invalid' } do
      it { bipbop.perfileconomico(documento: '9').should be_nil }
    end
    context 'document', vcr: { cassette_name: 'bipbop/perfileconomico/valid-document' } do
      it { bipbop.perfileconomico(documento: '09116059751').should == {"name"=>"RAFAEL DE LIMA PAULA", "gender" => "male", "approximate_age"=>"30", "hash"=>"6CzXsZA09xMgXrHmJHUNY5X0cu7fv5yXwPGVX/i7nVE6awYftn5LpsVvdeoqbuMfBGdKIm0t1F+jrdifMraoyA==", "criteria"=>"A1", "buy_limit"=>"10214.87", "buy_avg"=>"268.33"} }
    end
  end
end
